summaryrefslogtreecommitdiff
path: root/rsc
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2012-07-30 08:41:34 +0200
committerStephan Bergmann <sbergman@redhat.com>2012-07-30 09:26:00 +0200
commit889de665ec9d2ac25a9dccd4830cb97ed0c7c56e (patch)
treef98ed6e8215a39287248189841411e0edb0439c3 /rsc
parent291dcae246de9e32d9ca5926be463ad910c5bd1e (diff)
Typo ressource -> resource
Change-Id: Id13e7acfbe34eca5e124c9032d36d6f158bfb831
Diffstat (limited to 'rsc')
-rw-r--r--rsc/inc/rscall.h2
-rw-r--r--rsc/source/parser/erscerr.cxx2
-rw-r--r--rsc/source/rsc/rsc.cxx6
3 files changed, 5 insertions, 5 deletions
diff --git a/rsc/inc/rscall.h b/rsc/inc/rscall.h
index 9bddec4cb86b..789df421613d 100644
--- a/rsc/inc/rscall.h
+++ b/rsc/inc/rscall.h
@@ -64,7 +64,7 @@ extern AtomContainer* pHS;
#define INCLUDE_FLAG 0x0040 // der Include-Pfad wurde erweitert
#define MSCPREPRO_FLAG 0x0080 // spezial Preprozessor
#define PRINTSYNTAX_FLAG 0x0100 // Syntax ausgeben
-#define PRELOAD_FLAG 0x0200 // Alle Ressourcen Preloaden
+#define PRELOAD_FLAG 0x0200 // Alle Resourcen Preloaden
#define SMART_FLAG 0x0400 // abgekuertze Name
#define SRSDEFAULT_FLAG 0x1000 // immer der Default geschrieben
#define NOSYSRESTEST_FLAG 0x2000 // ueberprueft nicht die Richtigkeit von (bmp, ico, cur)
diff --git a/rsc/source/parser/erscerr.cxx b/rsc/source/parser/erscerr.cxx
index b2442f0036c6..e08cefa3c3f1 100644
--- a/rsc/source/parser/erscerr.cxx
+++ b/rsc/source/parser/erscerr.cxx
@@ -192,7 +192,7 @@ void RscError::WriteError( const ERRTYPE& rError, const char * pMessage )
StdLstOut( "-fh=<filename> Header file.\n" );
StdLstOut( "-fc=<filename> Code file.\n" );
StdLstOut( "-ft=<filename> Touch a file when done in rsc2 (for dependencies)\n" );
- StdLstOut( "-fr=<filename> Ressource constructor .cxx-file.\n" );
+ StdLstOut( "-fr=<filename> Resource constructor .cxx-file.\n" );
StdLstOut( "-fx=<filename> Name of .src-file.\n" );
StdLstOut( "-oil=<dir> Output directory for image list files\n" );
StdLstOut( "-r<ENV>=<path> replace <path> by <ENV> in image list files\n" );
diff --git a/rsc/source/rsc/rsc.cxx b/rsc/source/rsc/rsc.cxx
index cdf3ff4bdc42..d422de9e4380 100644
--- a/rsc/source/rsc/rsc.cxx
+++ b/rsc/source/rsc/rsc.cxx
@@ -176,7 +176,7 @@ RscCmdLine::RscCmdLine( int argc, char ** argv, RscError * pEH )
}
}
else if( !rsc_stricmp( (*ppStr) + 1, "PreLoad" ) )
- { // Alle Ressourcen mit Preload
+ { // Alle Resourcen mit Preload
nCommands |= PRELOAD_FLAG;
}
else if( !rsc_stricmp( (*ppStr) + 1, "LITTLEENDIAN" ) )
@@ -249,7 +249,7 @@ RscCmdLine::RscCmdLine( int argc, char ** argv, RscError * pEH )
aOutputCxx = (*ppStr) + 4;
}
else if( !rsc_strnicmp( (*ppStr) + 1, "fr=", 3 ) )
- { // Name fuer .cxx-file der Ressource Konstruktoren
+ { // Name fuer .cxx-file der Resource Konstruktoren
aOutputRcCtor = (*ppStr) + 4;
}
else if( !rsc_strnicmp( (*ppStr) + 1, "fx=", 3 ) )
@@ -992,7 +992,7 @@ ERRTYPE RscCompiler::Link()
if ( NULL == (fExitFile = foutput = fopen( aTmpOutputRcCtor.getStr(), "w" )) )
pTC->pEH->FatalError( ERR_OPENFILE, RscId(), aTmpOutputRcCtor.getStr() );
- pTC->pEH->StdOut( "Generating .cxx ressource constructor file\n" );
+ pTC->pEH->StdOut( "Generating .cxx resource constructor file\n" );
// Schreibe Datei
pTC->WriteRcCtor( foutput );